import setuptools 
from pathlib import Path 

setuptools.setup(
    name="zopdf",
    version=3.14,
    long_description=Path("README.md"). read_text(),
    packages=setuptools.find_packages(exclude=["tests", "data"])
)
